@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; frozen_string_literal: true -*-
 #
 #--
-# Copyright (C) 2009-2016 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2026 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -11,14 +11,8 @@ module Kramdown
   module Parser
     class Kramdown
 
-      if RUBY_VERSION == '1.8.5'
-        ACHARS = '\w\x80-\xFF'
-      elsif RUBY_VERSION < '1.9.0'
-        ACHARS = '\w'
-      else
-        ACHARS = '[[:alnum:]]_'
-      end
-      AUTOLINK_START_STR = "<((mailto|https?|ftps?):.+?|[-.#{ACHARS}]+@[-#{ACHARS}]+(?:\.[-#{ACHARS}]+)*\.[a-z]+)>"
+      ACHARS = '[[:alnum:]]-_.'
+      AUTOLINK_START_STR = "<((mailto|https?|ftps?):.+?|[#{ACHARS}]+?@[#{ACHARS}]+?)>"
       AUTOLINK_START = /#{AUTOLINK_START_STR}/u
 
       # Parse the autolink at the current location.
@@ -26,7 +20,7 @@ module Kramdown
         start_line_number = @src.current_line_number
         @src.pos += @src.matched_size
         href = (@src[2].nil? ? "mailto:#{@src[1]}" : @src[1])
-        el = Element.new(:a, nil, {'href' => href}, :location => start_line_number)
+        el = Element.new(:a, nil, {'href' => href}, location: start_line_number)
         add_text(@src[1].sub(/^mailto:/, ''), el)
         @tree.children << el
       end
