@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; frozen_string_literal: true -*-
 #
 #--
-# Copyright (C) 2009-2016 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2026 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -25,12 +25,11 @@ module Kramdown
         data = @src.scan(self.class::CODEBLOCK_MATCH)
         data.gsub!(/\n( {0,3}\S)/, ' \\1')
         data.gsub!(INDENT, '')
-        @tree.children << new_block_el(:codeblock, data, nil, :location => start_line_number)
+        @tree.children << new_block_el(:codeblock, data, nil, location: start_line_number)
         true
       end
       define_parser(:codeblock, CODEBLOCK_START)
 
-
       FENCED_CODEBLOCK_START = /^~{3,}/
       FENCED_CODEBLOCK_MATCH = /^((~){3,})\s*?((\S+?)(?:\?\S*)?)?\s*?\n(.*?)^\1\2*\s*?\n/m
 
@@ -39,7 +38,7 @@ module Kramdown
         if @src.check(self.class::FENCED_CODEBLOCK_MATCH)
           start_line_number = @src.current_line_number
           @src.pos += @src.matched_size
-          el = new_block_el(:codeblock, @src[5], nil, :location => start_line_number, :fenced => true)
+          el = new_block_el(:codeblock, @src[5], nil, location: start_line_number, fenced: true)
           lang = @src[3].to_s.strip
           unless lang.empty?
             el.options[:lang] = lang
