@@ -1,7 +1,7 @@
 # -*- coding: utf-8; frozen_string_literal: true -*-
 #
 #--
-# Copyright (C) 2009-2019 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2026 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -21,16 +21,20 @@ begin
   end
 
   # custom formatter for tests
-  class RougeHTMLFormatters < Kramdown::Converter::SyntaxHighlighter::Rouge.formatter_class
+  module Rouge
+    module Formatters
+      class RougeHTMLFormatters < Kramdown::Converter::SyntaxHighlighter::Rouge.formatter_class
 
-    tag 'rouge_html_formatters'
+        tag 'rouge_html_formatters'
 
-    def stream(tokens, &b)
-      yield %(<div class="custom-class">)
-      super
-      yield %(</div>)
+        def stream(tokens, &b)
+          yield %(<div class="custom-class">)
+          super
+          yield %(</div>)
+        end
+
+      end
     end
-
   end
 rescue LoadError, SyntaxError, NameError
 end
@@ -82,6 +86,7 @@ class TestFiles < Minitest::Test
       'test/testcases/span/05_html/mark_element.html', # bc of tidy
       'test/testcases/block/09_html/xml.html', # bc of tidy
       'test/testcases/span/05_html/xml.html', # bc of tidy
+      'test/testcases/block/04_header/with_header_links.html', # because of header_links option
     ].compact
     EXCLUDE_HTML_TEXT_FILES = [
       'test/testcases/block/09_html/parse_as_span.htmlinput',
@@ -134,6 +139,7 @@ class TestFiles < Minitest::Test
       'test/testcases/block/06_codeblock/with_lang_in_fenced_block_any_char.text',
       'test/testcases/block/03_paragraph/standalone_image.text', # bc of standalone image
       'test/testcases/cjk-line-break.text', # latex unicode support
+      'test/testcases/block/04_header/with_auto_ids.text', # bc of Unicode characters
     ].compact
     Dir[File.dirname(__FILE__) + '/testcases/**/*.text'].each do |text_file|
       next if EXCLUDE_LATEX_FILES.any? {|f| text_file =~ /#{f}$/ }
@@ -180,6 +186,7 @@ class TestFiles < Minitest::Test
       'test/testcases/block/03_paragraph/standalone_image.text', # bc of standalone image
       'test/testcases/cjk-line-break.text',
       'test/testcases/block/09_html/standalone_image_in_div.html', # bc of standalone image
+      'test/testcases/span/abbreviations/abbrev_in_html.text', # bc of invalid abbr tag in SVG
     ].compact
     Dir[File.dirname(__FILE__) + '/testcases/**/*.text'].each do |text_file|
       next if EXCLUDE_TEXT_FILES.any? {|f| text_file =~ /#{f}$/ }
@@ -192,6 +199,9 @@ class TestFiles < Minitest::Test
         kdtext = Kramdown::Document.new(File.read(text_file), options).to_kramdown
         html = Kramdown::Document.new(kdtext, options).to_html
         assert_equal(tidy_output(File.read(html_file)), tidy_output(html))
+        kdtext4 = Kramdown::Document.new(File.read(text_file), options.merge({list_indent: 4})).to_kramdown
+        html = Kramdown::Document.new(kdtext4, options).to_html
+        assert_equal(tidy_output(File.read(html_file)), tidy_output(html))
       end
     end
   end
@@ -232,6 +242,7 @@ class TestFiles < Minitest::Test
       'test/testcases/span/04_footnote/backlink_inline.html', # bc of mathjax
       'test/testcases/block/09_html/standalone_image_in_div.html', # bc of standalone image
       'test/testcases/block/09_html/processing_instruction.html', # bc of PI
+      'test/testcases/block/04_header/with_header_links.html', # bc of header_links option
     ].compact
     Dir[File.dirname(__FILE__) + '/testcases/**/*.html'].each do |html_file|
       next if EXCLUDE_HTML_KD_FILES.any? {|f| html_file =~ /#{f}$/ }
@@ -249,7 +260,7 @@ class TestFiles < Minitest::Test
 
   # Generate test methods for text-manpage conversion
   Dir[File.dirname(__FILE__) + '/testcases/man/**/*.text'].each do |text_file|
-    define_method('test_' + text_file.tr('.', '_') + "_to_man") do
+    define_method('test_' + text_file.tr('.', '_') + "_to_man_extra") do
       man_file = text_file.sub(/\.text$/, '.man')
       doc = Kramdown::Document.new(File.read(text_file))
       assert_equal(File.read(man_file), doc.to_man)
@@ -258,6 +269,7 @@ class TestFiles < Minitest::Test
 
   EXCLUDE_MODIFY = [
     'test/testcases/block/06_codeblock/rouge/multiple.text', # bc of HTMLFormater in options
+    'test/testcases/block/04_header/with_header_links.text', # bc of header_links option
   ].compact
 
   # Generate test methods for asserting that converters don't modify the document tree.
@@ -270,7 +282,11 @@ class TestFiles < Minitest::Test
       define_method("test_whether_#{conv_class}_modifies_tree_with_file_#{text_file.tr('.', '_')}") do
         doc = Kramdown::Document.new(File.read(text_file), options)
         options_before = Marshal.load(Marshal.dump(doc.options))
+        abbrev_proc = doc.root.options[:abbrev_defs].default_proc
+        doc.root.options[:abbrev_defs].default_proc = doc.root.options[:abbrev_attr].default_proc = nil
         tree_before = Marshal.load(Marshal.dump(doc.root))
+        doc.root.options[:abbrev_defs].default_proc = doc.root.options[:abbrev_attr].default_proc =
+          abbrev_proc
         Kramdown::Converter.const_get(conv_class).convert(doc.root, doc.options)
         assert_equal(options_before, doc.options)
         assert_tree_not_changed(tree_before, doc.root)
