@@ -1,26 +1,24 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; frozen_string_literal: true -*-
 #
 #--
-# Copyright (C) 2009-2016 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2026 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
 #
 
-
 require 'minitest/autorun'
 require 'kramdown'
 
-Encoding.default_external = 'utf-8' if RUBY_VERSION >= '1.9'
+Encoding.default_external = 'utf-8'
 
 describe 'location' do
-
   # checks that +element+'s :location option corresponds to the location stored
   # in the element.attr['class']
   def check_element_for_location(element)
     if (match = /^line-(\d+)/.match(element.attr['class'] || ''))
       expected_line = match[1].to_i
-      element.options[:location].must_equal(expected_line)
+      assert_equal(expected_line, element.options[:location])
     end
     element.children.each do |child|
       check_element_for_location(child)
@@ -176,7 +174,7 @@ describe 'location' do
     ),
   }
   test_cases.each do |name, test_string|
-    it "Handles #{ name }" do
+    it "Handles #{name}" do
       doc = Kramdown::Document.new(test_string.gsub(/^      /, '').strip)
       check_element_for_location(doc.root)
     end
@@ -189,13 +187,13 @@ describe 'location' do
 *[duplicate]: The second definition
     )
     doc = Kramdown::Document.new(test_string.strip)
-    doc.warnings.must_equal ["Duplicate abbreviation ID 'duplicate' on line 4 - overwriting"]
+    assert_equal(["Duplicate abbreviation ID 'duplicate' on line 4 - overwriting"], doc.warnings)
   end
 
   it 'handles abbreviations' do
     str = "This *is* ABC and\n**and** ABC second\nanother ABC\nas ABC as\nABC at the end.\n\n*[ABC]: ABC"
     doc = Kramdown::Document.new(str)
-    doc.root.children.first.children.select {|e| e.type == :abbreviation}.each_with_index do |e, i|
+    doc.root.children.first.children.select {|e| e.type == :abbreviation }.each_with_index do |e, i|
       assert_equal(i + 1, e.options[:location])
     end
   end
@@ -203,7 +201,7 @@ describe 'location' do
   it 'handles line breaks' do
     str = "First  \nsecond\\\\\nthird  \n"
     doc = Kramdown::Document.new(str)
-    doc.root.children.first.children.select {|e| e.type == :br}.each_with_index do |e, i|
+    doc.root.children.first.children.select {|e| e.type == :br }.each_with_index do |e, i|
       assert_equal(i + 1, e.options[:location])
     end
   end
@@ -211,28 +209,8 @@ describe 'location' do
   it 'handles smart quotes' do
     str = "This is 'first'\nand 'second' and\n'third'"
     doc = Kramdown::Document.new(str)
-    doc.root.children.first.children.select {|e| e.type == :smart_quote}.each_with_index do |e, i|
-      assert_equal(((i + 1) /2.0).ceil, e.options[:location])
+    doc.root.children.first.children.select {|e| e.type == :smart_quote }.each_with_index do |e, i|
+      assert_equal(((i + 1) / 2.0).ceil, e.options[:location])
     end
   end
-
-  it 'handles hard wrapped paragraphs with the GFM parser' do
-    str = "A*b*C\nA*b*C\nA*b*C"
-    doc = Kramdown::Document.new(str, :input => 'GFM', :hard_wrap => true)
-    para = doc.root.children.first
-    1.upto(3) do |line|
-      0.upto(line == 3 ? 2 : 3) do |element|
-        assert_equal(line, para.children[4*(line - 1) + element].options[:location])
-      end
-    end
-  end
-
-  it 'marks fenced code block as fenced with the GFM parser' do
-    str = %(```\nfenced code\n```\n\n    indented code\n)
-    doc = Kramdown::Document.new(str, :input => 'GFM')
-    fenced_cb = doc.root.children.first
-    indented_cb = doc.root.children.last
-    assert fenced_cb.options[:fenced]
-    refute indented_cb.options[:fenced]
-  end
 end
